@@ -965,7 +965,7 @@ int WOWatchDogApplicationMain
   NSAutoreleasePool *pool;
   NSUserDefaults *ud;
   NSString *logFile, *nsPidFile;
-  int rc;
+  int rc, i;
   pid_t childPid;
   NSProcessInfo *processInfo;
   Class WOAppClass;
@@ -993,6 +993,11 @@ int WOWatchDogApplicationMain
     logFile = [NSString stringWithFormat: @"/var/log/%@/%@.log",
                         [processInfo processName],
                         [processInfo processName]];
+
+  /* Close all open file descriptors */
+  for (i = getdtablesize(); i >= 3; --i)
+    close(i);
+  freopen("/dev/null", "a", stdin);
   if (![logFile isEqualToString: @"-"]) {
     freopen([logFile cString], "a", stdout);
     freopen([logFile cString], "a", stderr);
@@ -1064,12 +1069,12 @@ int WOWatchDogApplicationMainWithServerDefaults
 #endif
   
   if ((defClass = NSClassFromString(@"WOServerDefaults")) != nil) {
-    NSUserDefaults *ud, *sd;
+    NSUserDefaults *ud;
     
     ud = [NSUserDefaults standardUserDefaults];
-    sd = [defClass hackInServerDefaults:ud
-                      withAppDomainPath:appDomainPath
-                       globalDomainPath:globalDomainPath];
+    [defClass hackInServerDefaults:ud
+              withAppDomainPath:appDomainPath
+              globalDomainPath:globalDomainPath];
 
 #if 0    
     if (((sd == nil) || (sd == ud)) && (appDomainPath != nil)) {
@@ -1078,6 +1083,8 @@ int WOWatchDogApplicationMainWithServerDefaults
     }
 #endif
   }
-  
+ 
+  [pool release];
+
   return WOWatchDogApplicationMain(appName, argc, argv);
 }
